@@ -33,7 +33,8 @@ class Command:
             self.title = title
 
         self.func = func
-
+        self.func_name = self.func.__name__
+    
     def extension(self, ext_name):
         return f"{ext_name}.{self.name}"
 
@@ -42,7 +43,7 @@ class Command:
         return temp[0] + "".join(ele.title() for ele in temp[1:])
 
     def convert_snake_to_title(self, text):
-        return "".join(text.split("_")).title()
+        return text.replace("_", " ").title()
 
     def __repr__(self):
         return f"<vscode.Command {self.name}>"
